==> kubernetes-model-core-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/QuobyteVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QuobyteVolumeSourceFluentImpl<A extends QuobyteVolumeSourceFluent<A>> extends BaseFluent<A> implements QuobyteVolumeSourceFluent<A>{
  public QuobyteVolumeSourceFluentImpl() {
  }
  public QuobyteVolumeSourceFluentImpl(QuobyteVolumeSource instance) {
    this.withGroup(instance.getGroup()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withRegistry(instance.getRegistry()); 
    this.withTenant(instance.getTenant()); 
    this.withUser(instance.getUser()); 
    this.withVolume(instance.getVolume()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String group;
  private Boolean readOnly;
  private String registry;
  private String tenant;
  private String user;
  private String volume;
  private Map<String,Object> additionalProperties;
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  public String getRegistry() {
    return this.registry;
  }
  public A withRegistry(String registry) {
    this.registry=registry; return (A) this;
  }
  public Boolean hasRegistry() {
    return this.registry != null;
  }
  public String getTenant() {
    return this.tenant;
  }
  public A withTenant(String tenant) {
    this.tenant=tenant; return (A) this;
  }
  public Boolean hasTenant() {
    return this.tenant != null;
  }
  public String getUser() {
    return this.user;
  }
  public A withUser(String user) {
    this.user=user; return (A) this;
  }
  public Boolean hasUser() {
    return this.user != null;
  }
  public String getVolume() {
    return this.volume;
  }
  public A withVolume(String volume) {
    this.volume=volume; return (A) this;
  }
  public Boolean hasVolume() {
    return this.volume != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QuobyteVolumeSourceFluentImpl that = (QuobyteVolumeSourceFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (registry != null ? !registry.equals(that.registry) :that.registry != null) return false;
    if (tenant != null ? !tenant.equals(that.tenant) :that.tenant != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (volume != null ? !volume.equals(that.volume) :that.volume != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  readOnly,  registry,  tenant,  user,  volume,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (readOnly != null) { sb.append("readOnly:"); sb.append(readOnly + ","); }
    if (registry != null) { sb.append("registry:"); sb.append(registry + ","); }
    if (tenant != null) { sb.append("tenant:"); sb.append(tenant + ","); }
    if (user != null) { sb.append("user:"); sb.append(user + ","); }
    if (volume != null) { sb.append("volume:"); sb.append(volume + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withReadOnly() {
    return withReadOnly(true);
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/QuobyteVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QuobyteVolumeSourceFluentImpl<A extends QuobyteVolumeSourceFluent<A>> extends BaseFluent<A> implements QuobyteVolumeSourceFluent<A>{
  public QuobyteVolumeSourceFluentImpl() {
  }
  public QuobyteVolumeSourceFluentImpl(QuobyteVolumeSource instance) {
    if (instance != null) {
      this.withGroup(instance.getGroup());
      this.withReadOnly(instance.getReadOnly());
      this.withRegistry(instance.getRegistry());
      this.withTenant(instance.getTenant());
      this.withUser(instance.getUser());
      this.withVolume(instance.getVolume());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String group;
  private Boolean readOnly;
  private String registry;
  private String tenant;
  private String user;
  private String volume;
  private Map<String,Object> additionalProperties;
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  public String getRegistry() {
    return this.registry;
  }
  public A withRegistry(String registry) {
    this.registry=registry; return (A) this;
  }
  public Boolean hasRegistry() {
    return this.registry != null;
  }
  public String getTenant() {
    return this.tenant;
  }
  public A withTenant(String tenant) {
    this.tenant=tenant; return (A) this;
  }
  public Boolean hasTenant() {
    return this.tenant != null;
  }
  public String getUser() {
    return this.user;
  }
  public A withUser(String user) {
    this.user=user; return (A) this;
  }
  public Boolean hasUser() {
    return this.user != null;
  }
  public String getVolume() {
    return this.volume;
  }
  public A withVolume(String volume) {
    this.volume=volume; return (A) this;
  }
  public Boolean hasVolume() {
    return this.volume != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QuobyteVolumeSourceFluentImpl that = (QuobyteVolumeSourceFluentImpl) o;
    if (!java.util.Objects.equals(group, that.group)) return false;

    if (!java.util.Objects.equals(readOnly, that.readOnly)) return false;

    if (!java.util.Objects.equals(registry, that.registry)) return false;

    if (!java.util.Objects.equals(tenant, that.tenant)) return false;

    if (!java.util.Objects.equals(user, that.user)) return false;

    if (!java.util.Objects.equals(volume, that.volume)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  readOnly,  registry,  tenant,  user,  volume,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (readOnly != null) { sb.append("readOnly:"); sb.append(readOnly + ","); }
    if (registry != null) { sb.append("registry:"); sb.append(registry + ","); }
    if (tenant != null) { sb.append("tenant:"); sb.append(tenant + ","); }
    if (user != null) { sb.append("user:"); sb.append(user + ","); }
    if (volume != null) { sb.append("volume:"); sb.append(volume + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withReadOnly() {
    return withReadOnly(true);
  }
  
}
